@@ -20,44 +20,50 @@
  */
 
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include "kz-actions-download.h"
 #include "kz-downloader-group.h"
-#include "kz-mozembed.h"
-#include "intl.h"
 #include "gtk-utils.h"
 
 static void act_download_do (const gchar *uri,
 			     const gchar* filename,
 			     gboolean content);
 
-const gchar *
-kz_actions_download_open_save_dialog (const gchar *uri, gboolean content)
+gchar *
+kz_actions_download_open_save_dialog (GtkWindow *window, 
+    				      const gchar *uri,
+				      gboolean content)
 {
-	GtkFileSelection *file_selector;
+	GtkWidget *file_dialog;
 	const gchar *basename = NULL;
-	const gchar *selected_filename;
+	gchar *selected_filename = NULL;
 	gint result;
 
 	if (!uri) return NULL;
 
 	basename = g_path_get_basename(uri);
-	
-	/* Create the selector */
-	file_selector = GTK_FILE_SELECTION(gtk_file_selection_new ("Save file"));
+
+	file_dialog = gtk_file_chooser_dialog_new (_("Save file"),
+						   window, 
+						   GTK_FILE_CHOOSER_ACTION_SAVE,
+						   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						   GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+						   NULL);
+
 	/* set default filename created from uri */
-	gtk_file_selection_set_filename(file_selector, basename);
+	gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(file_dialog), basename);
 
 	/* Display that dialog */
-	result = gtk_dialog_run(GTK_DIALOG(file_selector));
-	
+	result = gtk_dialog_run(GTK_DIALOG(file_dialog));
+
 	switch (result)
 	{
-	 case GTK_RESPONSE_OK:
-		selected_filename = gtk_file_selection_get_filename(file_selector);
+	 case GTK_RESPONSE_ACCEPT:
+		selected_filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(file_dialog));
 		if (g_file_test(selected_filename, G_FILE_TEST_EXISTS))
 		{
 			gboolean ret;
-			ret = gtkutil_confirm_file_replace(GTK_WINDOW(file_selector),
+			ret = gtkutil_confirm_file_replace(GTK_WINDOW(file_dialog),
 							   selected_filename);
 			if (!ret)
 				break;
@@ -65,7 +71,7 @@ kz_actions_download_open_save_dialog (const gchar *uri, gboolean content)
 		/* FIXME! it's the hacky way! */
 		if (content)
 		{
-			gtk_widget_destroy(GTK_WIDGET(file_selector));
+			gtk_widget_destroy(file_dialog);
 			return selected_filename;
 		}
 
@@ -74,7 +80,10 @@ kz_actions_download_open_save_dialog (const gchar *uri, gboolean content)
 	 default:
 		break;
 	}
-	gtk_widget_destroy(GTK_WIDGET(file_selector));
+	gtk_widget_destroy(file_dialog);
+
+	if (selected_filename)
+		g_free(selected_filename);
 
 	return NULL;
 }
@@ -88,5 +97,6 @@ act_download_do (const gchar *uri, const gchar* filename, gboolean content)
 
 	dlgrp = kz_downloader_group_get_instance();
 	kz_downloader_group_add_item_with_filename(dlgrp, uri, filename);
+	g_warning("%s", filename);
 	g_object_unref(dlgrp);
 }
