@@ -25,6 +25,7 @@
 #include "gtk-utils.h"
 #include "kazehakase.h"
 #include "kz-icons.h"
+#include "kz-actions-dynamic.h"
 
 static GQuark kztab_quark = 0;
 
@@ -227,58 +228,6 @@ act_tab_copy_title_and_location (GtkAction *action, KzWindow *kz)
 	g_free(str);
 }
 
-static void
-act_tab_copy_in_user_format (GtkAction *action, KzWindow *kz)
-{
-	KzTabLabel *kztab;
-	gchar *format;
-	gchar **splited = NULL;
-	gint counts = 0;
-	gint i;
-	gchar *str = NULL;
-
-	g_return_if_fail(KZ_IS_WINDOW(kz));
-
-	kztab = get_tab_object(kz);
-	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
-
-	format = KZ_CONF_GET_STR("Global" , "copy_tab_format1");
-	if(!format) return;
-
-	for(i = 0;format[i] != '\0';i++)
-		if(format[i] == '%') counts++;
-	counts++;
-	
-	if(counts != 1)
-	{
-		gchar **temp = g_new0(gchar*, counts + 1);
-		splited = g_strsplit(format , "%" , counts);
-
-		for (i = 0;i < counts;i++)
-		{
-			if (splited[i][0] == 't')
-				temp[i] = (gchar*)kz_embed_get_title(KZ_EMBED(kztab->kzembed));
-			else if(splited[i][0] == 'u')
-				temp[i] = (gchar*)kz_embed_get_location(KZ_EMBED(kztab->kzembed));
-			else
-				temp[i] = splited[i];
-		}
-		temp[counts] = NULL;
-
-		str = g_strjoinv(NULL , temp);
-		g_strfreev(splited);
-	}
-	else
-	{
-		str = g_strdup(format);
-	}
-
-	g_free(format);
-
-	gtkutil_copy_text(str);
-
-	if(str)	g_free(str);
-}
 
 static void
 act_tab_toggle_lock (GtkAction *action, KzWindow *kz)
@@ -395,9 +344,6 @@ GtkActionEntry kz_actions_tab[] =
 	{"TabCopyTitleLocation",     NULL, N_("Cop_y Title&Location"),
 	 NULL, NULL, G_CALLBACK(act_tab_copy_title_and_location)},
 
-	{"TabCopyInUserFormat",     NULL, N_("Cop_y _In user format"),
-	 NULL, NULL, G_CALLBACK(act_tab_copy_in_user_format)},
-
 	{"TabCopy",     NULL, N_("Tab Co_py"),
 	 NULL, NULL, G_CALLBACK(act_tab_copy_tab)},
 };
@@ -523,6 +469,7 @@ void
 kz_actions_tab_popup_menu_modal (KzTabLabel *kztab, guint button, guint time)
 {
 	GtkWidget *popup_menu = NULL;
+	GtkWidget *extra_menu = NULL;
 	
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 	g_return_if_fail(KZ_IS_WINDOW(kztab->kz));
@@ -536,12 +483,21 @@ kz_actions_tab_popup_menu_modal (KzTabLabel *kztab, guint button, guint time)
 					       "/TabPopup");
 	if (!popup_menu) return;
 
+        /* add copy in user format */
+	extra_menu = gtk_ui_manager_get_widget(kztab->kz->menu_merge,
+					       "/TabPopup/CopyInUserFormat");
+	if(extra_menu)
+	{
+		kz_actions_dynamic_append_copy_in_user_format_menuitem
+			(kztab, GTK_MENU_ITEM(extra_menu));
+	}
+
 	set_popup_menu_sensitive(kztab);
 
 	g_signal_connect(popup_menu, "hide",
 			 G_CALLBACK(cb_popup_menu_hide), NULL);
 	gtk_menu_popup(GTK_MENU(popup_menu), NULL, NULL,
-		       NULL, NULL, button, time);
+		       NULL, NULL, 0, time);
 	gtk_main();
 	g_signal_handlers_disconnect_by_func(popup_menu,
 					     G_CALLBACK(cb_popup_menu_hide),
