@@ -33,6 +33,7 @@
 #include "kz-prefs-win.h"
 #include "kz-links-dialog.h"
 #include "kz-password-manager-dialog.h"
+#include "kz-copy-format-dialog.h"
 #include "kz-smart-bookmark.h"
 #include "kz-bookmark.h"
 #include "kz-bookmark-editor.h"
@@ -1634,6 +1635,16 @@ act_show_password_manager (GtkAction *action, KzWindow *kz)
 	gtk_widget_show(dialog);
 }
 
+static void
+act_show_copy_format(GtkAction *action, KzWindow *kz)
+{
+	GtkWidget *dialog;
+
+	dialog = kz_copy_format_dialog_new(kz);
+	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(kz));
+	gtk_widget_show(dialog);
+}
+
 static void
 act_decrease_text_size (GtkAction *action, KzWindow *kz)
 {
@@ -1973,7 +1984,7 @@ GtkActionEntry kz_actions[] =
   {"SelectAll", KZ_STOCK_SELECT_ALL,            N_("Select _All"),    CTRL"A", N_("Select the entire page"), G_CALLBACK(act_select_all)},
   {"CopyTitle",          NULL          ,        N_("Copy _Title"),    NULL,    N_("Copy the title of the current page"), G_CALLBACK(act_copy_title)},
   {"CopyURL",            KZ_STOCK_COPY_URL,     N_("Copy _URL"),      NULL,    N_("Copy the URL of the current page"), G_CALLBACK(act_copy_url)},
-  {"CopyInUserFormat",          NULL          ,        N_("Copy _In User Format"),    NULL,    N_("Copy Title, URI and Selected text in user format"), G_CALLBACK(act_copy_in_user_format)},
+  {"CopyInUserFormat",          NULL          ,        N_("Copy _In User Format"),    NULL,    N_("Copy Title, URI and Selected text in user format"), NULL}, 
   {"Preference",         GTK_STOCK_PREFERENCES, N_("_Preference..."), NULL,    N_("Preference"), G_CALLBACK(act_preference)},
   {"DetailedPreference", NULL                 , N_("_Detailed Preference"), NULL, N_("Detailed preference"), G_CALLBACK(act_detaild_preference)},
 
@@ -2049,6 +2060,7 @@ GtkActionEntry kz_actions[] =
   /* {"DeleteSession", NULL, N_("Delete current session"),     NULL, NULL, G_CALLBACK(act_save_session)}, */
   /* {"SwitchSession", NULL, N_("Switch current session ..."), NULL, NULL, G_CALLBACK(act_switch_session)}, */
   {"ShowPassword", NULL, N_("_Show Password Manager"), NULL,  NULL, G_CALLBACK(act_show_password_manager)},
+  {"ShowCopyFormat", NULL, N_("_Show Copy Format"), NULL,  NULL, G_CALLBACK(act_show_copy_format)},
   {"About",        NULL, N_("About Kazehakase"),       NULL,  N_("Display credits"), G_CALLBACK(act_about)},
   
   {"PopupContextMenu", NULL, N_("Popup context menu"), SHFT"F10",  N_("Popup context menu"), G_CALLBACK(act_popup_context_menu)},
