@@ -25,6 +25,8 @@
 #include <stdlib.h>
 #include <gdk/gdkkeysyms.h>
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 #include <glib/gi18n.h>
 
 #include "kazehakase.h"
@@ -33,6 +35,7 @@
 #include "kz-bookmark.h"
 #include "kz-smart-bookmark.h"
 #include "kz-actions.h"
+#include "eggregex.h"
 
 #define KZ_LOCATION_ENTRY_ACTION_KEY "KzLocationEntryAction::Action"
 
@@ -62,6 +65,10 @@ static void kz_location_entry_action_disconnect_proxy (GtkAction         *action
 
 static void     kz_location_entry_action_history_changed (KzHistoryAction *action);
 static void     kz_location_entry_action_sync_history    (KzLocationEntryAction *action);
+static void     kz_location_entry_action_reset_history   (KzLocationEntryAction *action);
+static void     kz_location_entry_action_clear_history   (KzLocationEntryAction *action);
+static void     cb_editable_changed                      (GtkEditable *editable,
+							  KzLocationEntryAction *action);
 static gboolean cb_entry_key_press                       (GtkWidget *widget,
 							  GdkEventKey *event,
 							  KzLocationEntryAction *action);
@@ -69,7 +76,7 @@ static void     cb_entry_populate_popup         	 (GtkEntry *entry,
 						   	  GtkMenu *menu,
 	  			    	 	   	  KzLocationEntryAction *action);
 
-static void     cb_profile_entry_changed     (KzProfile       *profile,
+static void     cb_profile_global_changed     (KzProfile       *profile,
 					       const gchar     *section,
 					       const gchar     *key,
 					       const gchar     *old_value,
@@ -152,11 +159,7 @@ kz_location_entry_action_dispose (GObject *obj)
 		action->kz = NULL;
 	}
 
-	if (action->history)
-	{
-		g_object_unref(action->history);
-		action->history = NULL;
-	}
+	kz_location_entry_action_clear_history(action);
 
 	if (action->bookmark)
 	{
@@ -226,10 +229,13 @@ kz_location_entry_action_activate (GtkAction *action)
 	gboolean new_tab;
 	GdkModifierType state = (GdkModifierType)0;
 	gint x, y;
+	guint new_tab_mask = GDK_CONTROL_MASK;
  
 	g_return_if_fail(KZ_IS_LOCATION_ENTRY_ACTION(action));
 	entry_action = KZ_LOCATION_ENTRY_ACTION(action);
 
+	kz_location_entry_action_reset_history(entry_action);
+	
 	entry_action->activating = TRUE;
 	if (GTK_ACTION_CLASS(parent_class)->activate)
 		GTK_ACTION_CLASS(parent_class)->activate(action);
@@ -241,8 +247,9 @@ kz_location_entry_action_activate (GtkAction *action)
 
 	gdk_window_get_pointer(NULL, &x, &y, &state);
 	
+	KZ_CONF_GET("Tab" , "new_tab_mask" , new_tab_mask , INT);
 	KZ_CONF_GET("Global", "entry_open_in_new_tab", new_tab, BOOL);
-	new_tab = (state & GDK_CONTROL_MASK) ? !new_tab: new_tab;
+	new_tab = (state & new_tab_mask) ? !new_tab: new_tab;
 
 	if (new_tab)
 		kz_window_open_new_tab(entry_action->kz, smart_uri);
@@ -270,12 +277,14 @@ kz_location_entry_action_connect_proxy (GtkAction *action, GtkWidget *proxy)
 		g_object_set_data(G_OBJECT(entry),
 				  KZ_LOCATION_ENTRY_ACTION_KEY,
 				  action);
+		g_signal_connect(entry, "changed",
+				 G_CALLBACK(cb_editable_changed), action);
 		g_signal_connect(entry, "key-press-event",
 				 G_CALLBACK(cb_entry_key_press), action);
 		g_signal_connect(entry, "populate-popup",
 				 G_CALLBACK(cb_entry_populate_popup), action);
-		g_signal_connect(kz_global_profile, "changed::Entry",
-				 G_CALLBACK(cb_profile_entry_changed), entry);
+		g_signal_connect(kz_global_profile, "changed::Global",
+				 G_CALLBACK(cb_profile_global_changed), entry);
 	}
 }
 
@@ -288,6 +297,10 @@ kz_location_entry_action_disconnect_proxy (GtkAction *action, GtkWidget *proxy)
 	entry = kz_entry_action_get_entry_widget(KZ_ENTRY_ACTION(action), proxy);
 	if (entry)
 	{
+		g_signal_handlers_disconnect_by_func
+			(entry,
+			 G_CALLBACK(cb_editable_changed),
+			 action);
 		g_signal_handlers_disconnect_by_func
 			(entry,
 			 G_CALLBACK(cb_entry_key_press),
@@ -298,7 +311,7 @@ kz_location_entry_action_disconnect_proxy (GtkAction *action, GtkWidget *proxy)
 			 action);
 		g_signal_handlers_disconnect_by_func
 			(kz_global_profile,
-			 G_CALLBACK(cb_profile_entry_changed),
+			 G_CALLBACK(cb_profile_global_changed),
 			 entry);
 	        g_object_set_data(G_OBJECT(entry),
 		        	  KZ_LOCATION_ENTRY_ACTION_KEY,
@@ -421,6 +434,8 @@ kz_location_entry_action_restore_history (KzLocationEntryAction *action)
 	g_list_foreach(history, (GFunc) g_free, NULL);
 	g_list_free(history);
 
+	kz_location_entry_action_clear_history(action);
+	
 	kz_entry_action_set_text(KZ_ENTRY_ACTION(action), text);
 	g_free(text);
 }
@@ -457,30 +472,180 @@ kz_location_entry_action_sync_history (KzLocationEntryAction *action)
 	action->synchronizing = FALSE;
 }
 
+static void
+kz_location_entry_action_reset_history(KzLocationEntryAction *action)
+{
+	if (action->history)
+	{
+		kz_history_action_set_history(KZ_HISTORY_ACTION(action),
+					      action->history);
+		kz_location_entry_action_clear_history(action);
+	}
+}
+
+static void
+kz_location_entry_action_clear_history(KzLocationEntryAction *action)
+{
+	if (action->history)
+	{
+		g_list_foreach(action->history, (GFunc)g_free, NULL);
+		g_list_free(action->history);
+		action->history = NULL;
+	}
+}
+
+
+static void
+get_file_path_from_uri(const gchar *uri, gchar **path, gchar **prefix)
+{
+	GError *error = NULL;
+	EggRegex *regex;
+
+	*path = NULL;
+	*prefix = NULL;
+
+	g_return_if_fail(uri);
+	
+	regex = egg_regex_new("^\\s*(file://|)(/.*)\\s*",
+			      EGG_REGEX_CASELESS | EGG_REGEX_EXTENDED,
+			      0, &error);
+
+	if (error)
+	{
+		g_warning("%s", error->message);
+		g_error_free(error);
+		return;
+	}
+	
+	if (egg_regex_match(regex, uri, -1, 0) > 0)
+	{
+		*prefix = egg_regex_fetch(regex, uri, 1);
+		*path = egg_regex_fetch(regex, uri, 2);
+	}
+	
+	egg_regex_free(regex);
+}
+
+static gboolean
+is_dir(const gchar *path)
+{
+	gboolean result = FALSE;
+	struct stat buf;
+
+	if (stat(path, &buf) == 0)
+	{
+		result = S_ISDIR(buf.st_mode);
+	}
+
+	return result;
+}
+
+static void
+kz_location_entry_action_add_file_path_to_history(KzLocationEntryAction *action,
+						  const gchar *path,
+						  const gchar *prefix)
+{
+	GDir *dir;
+	gchar *dir_name = g_path_get_dirname(path);
+	gchar *base_name = g_path_get_basename(path);
+
+	dir = g_dir_open(dir_name, 0, NULL);
+
+	if (dir)
+	{
+		GList *list = g_list_alloc();
+		gchar *dir_base_name = g_path_get_basename(dir_name);
+		gboolean is_dir_path = (strcmp(base_name, dir_base_name) == 0);
+		const gchar *name;
+		gchar *full_path;
+		gchar *full_uri;
+			
+		for (name = g_dir_read_name(dir);
+		     name;
+		     name = g_dir_read_name(dir))
+		{
+			
+			if (!is_dir_path &&
+			    strncmp(base_name, name, strlen(base_name)) != 0)
+				continue;
+				
+			full_path = g_build_filename(dir_name, name, NULL);
+			full_uri = g_strconcat(prefix, full_path,
+					       is_dir(full_path) ? G_DIR_SEPARATOR_S : NULL,
+					       NULL);
+			list = g_list_append(list, full_uri);
+			
+			g_free(full_path);
+		}
+		
+		g_dir_close(dir);
+
+		g_list_concat(list,
+			      kz_history_action_get_history(KZ_HISTORY_ACTION(action)));
+		kz_history_action_set_history(KZ_HISTORY_ACTION(action), list);
+
+		g_free(dir_base_name);
+		g_list_foreach(list, (GFunc)g_free, NULL);
+		g_list_free(list);
+	}
+
+	g_free(base_name);
+	g_free(dir_name);
+}
+
+static void
+kz_location_entry_action_setup_file_completion(KzLocationEntryAction *action)
+{
+	const gchar *uri = kz_entry_action_get_text(KZ_ENTRY_ACTION(action));
+	gchar *path, *prefix;
+	
+	get_file_path_from_uri(uri, &path, &prefix);
+	
+	if (path)
+	{
+		if (action->history)
+		{
+			kz_history_action_set_history(KZ_HISTORY_ACTION(action),
+						      action->history);
+		}
+		else
+		{
+			action->history =
+				kz_history_action_get_history(KZ_HISTORY_ACTION(action));
+		}
+		kz_location_entry_action_add_file_path_to_history(action,
+								  path,
+								  prefix);
+		g_free(path);
+		g_free(prefix);
+	}
+	else
+	{
+		kz_location_entry_action_reset_history(action);
+	}
+}
+
+
+static void
+cb_editable_changed (GtkEditable *editable, KzLocationEntryAction *action)
+{
+	if (KZ_HISTORY_ACTION(action)->completion)
+		kz_location_entry_action_setup_file_completion(action);
+}
+
 
 static gboolean
 cb_entry_key_press (GtkWidget *widget, GdkEventKey *event,
 		    KzLocationEntryAction *action)
 {
-	gboolean new_tab;
+	guint new_tab_mask = GDK_CONTROL_MASK;
+
+	KZ_CONF_GET("Tab" , "new_tab_mask" , new_tab_mask , INT);
 
 	if ((event->keyval == GDK_Return || event->keyval == GDK_ISO_Enter)
-	    && (event->state & GDK_CONTROL_MASK))
+	    && (event->state & new_tab_mask))
 	{
-		const gchar *uri;
-		gchar *smart_uri;
-
-		KZ_CONF_GET("Global", "entry_open_in_new_tab", new_tab, BOOL);
-
-		uri = kz_entry_action_get_text(KZ_ENTRY_ACTION(action));
-		smart_uri = kz_smart_bookmark_get_smart_uri(
-				KZ_SMART_BOOKMARK(KZ_LOCATION_ENTRY_ACTION(action)->bookmark), uri);
-		if (new_tab)
-			kz_window_load_url(action->kz, smart_uri);
-		else 
-			kz_window_open_new_tab(action->kz, smart_uri);
-		g_free(smart_uri);
-
+		gtk_action_activate(GTK_ACTION(action));
 		return TRUE;
 	}
 
@@ -531,10 +696,10 @@ kz_location_entry_action_set_bookmark (KzLocationEntryAction *action,
 
 
 static void
-cb_profile_entry_changed (KzProfile *profile,
-			  const gchar *section, const gchar *key,
-			  const gchar *old_value,
-			  GtkEntry    *entry)
+cb_profile_global_changed (KzProfile *profile,
+			   const gchar *section, const gchar *key,
+			   const gchar *old_value,
+			   GtkEntry    *entry)
 {
      	if (!GTK_IS_ENTRY(entry)) return;
 	
@@ -558,6 +723,22 @@ cb_profile_entry_changed (KzProfile *profile,
 	                               kz_history_unset_completion (KZ_HISTORY_ACTION(action), entry);
                         }
 		}
+		else if (strcmp(key, "use_inline_completion") == 0)
+		{
+			GtkAction *action;
+	                
+			action = g_object_get_data(G_OBJECT(entry),
+        			        	   KZ_LOCATION_ENTRY_ACTION_KEY);
+			if (action && KZ_IS_HISTORY_ACTION(action))
+                        {
+		                gboolean inline_completion = FALSE;
+        		        KZ_CONF_GET("Global", "use_inline_completion",
+					    inline_completion, BOOL);
+				kz_history_set_inline_completion(KZ_HISTORY_ACTION(action),
+								 inline_completion);
+			}
+		}
+		break;
 	default:
 		break;
 	}
