@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark.c,v 1.74 2004/12/05 08:06:06 tyuyu Exp $
+ *  $Id: kz-bookmark.c,v 1.76 2005/02/13 22:55:15 ikezoe Exp $
  */
 
 #include "kz-bookmark.h"
@@ -340,8 +340,6 @@ kz_bookmark_dispose (GObject *object)
 {
 	KzBookmark *bookmark;
 	
-	g_return_if_fail(KZ_IS_BOOKMARK(object));
-
 	bookmark = KZ_BOOKMARK(object);
 
 	kz_bookmark_remove_all(bookmark);
@@ -796,7 +794,7 @@ kz_bookmark_insert_before (KzBookmark *bookmark,
 {
 	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 
-	g_signal_emit(G_OBJECT(bookmark),
+	g_signal_emit(bookmark,
 		      kz_bookmark_signals[INSERT_CHILD_SIGNAL], 0,
 		      child, sibling);
 }
@@ -847,7 +845,7 @@ kz_bookmark_real_remove_child (KzBookmark *bookmark, KzBookmark *child)
 void
 kz_bookmark_remove (KzBookmark *bookmark, KzBookmark *child)
 {
-	g_signal_emit(G_OBJECT(bookmark),
+	g_signal_emit(bookmark,
 		      kz_bookmark_signals[REMOVE_CHILD_SIGNAL], 0,
 		      child);
 }
@@ -1056,7 +1054,7 @@ kz_bookmark_sort (KzBookmark *bookmark, const gchar *type)
 
 	g_object_set_qdata(G_OBJECT(bookmark), children_quark, children);
 
-	g_signal_emit(G_OBJECT(bookmark),
+	g_signal_emit(bookmark,
 		      kz_bookmark_signals[CHILDREN_REORDERED_SIGNAL], 0);
 }
 
