@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmarks-view.c,v 1.25 2005/04/22 04:44:38 ikezoe Exp $
+ *  $Id: kz-bookmarks-view.c,v 1.26 2005/05/09 01:20:12 ikezoe Exp $
  */
 
 #include "kz-bookmarks-view.h"
@@ -46,13 +46,15 @@ enum {
 };
 
 
-struct _KzBookmarksViewPriv
+typedef struct _KzBookmarksViewPrivate	KzBookmarksViewPrivate;
+struct _KzBookmarksViewPrivate
 {
 	gboolean include_top;
 	gboolean folder_only;
 	gboolean tree_mode;
 	gboolean editable;
 };
+#define KZ_BOOKMARKS_VIEW_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_BOOKMARKS_VIEW, KzBookmarksViewPrivate))
 
 
 static void     kz_bookmarks_view_class_init (KzBookmarksViewClass *klass);
@@ -117,7 +119,6 @@ static GtkTreeViewClass *parent_class = NULL;
 KZ_OBJECT_GET_TYPE(kz_bookmarks_view, "KzBookmarksView", KzBookmarksView,
 		   kz_bookmarks_view_class_init, kz_bookmarks_view_init,
 		   GTK_TYPE_TREE_VIEW)
-KZ_OBJECT_FINALIZE(kz_bookmarks_view, KzBookmarksView)
 
 
 static void
@@ -132,7 +133,6 @@ kz_bookmarks_view_class_init (KzBookmarksViewClass *klass)
 	widget_class  = (GtkWidgetClass *) klass;
 
 	gobject_class->dispose      = kz_bookmarks_view_dispose;
-	gobject_class->finalize     = kz_bookmarks_view_finalize;
 #if 0
 	gobject_class->set_property = kz_bookmarks_view_set_property;
 	gobject_class->get_property = kz_bookmarks_view_get_property;
@@ -158,19 +158,20 @@ kz_bookmarks_view_class_init (KzBookmarksViewClass *klass)
 			TRUE,
 			G_PARAM_READWRITE));
 #endif
+	g_type_class_add_private (gobject_class, sizeof(KzBookmarksViewPrivate));
 }
 
 
 static void
 kz_bookmarks_view_init (KzBookmarksView *view)
 {
+	KzBookmarksViewPrivate *priv = KZ_BOOKMARKS_VIEW_GET_PRIVATE (view);
 	view->root_folder = NULL;
 
-	view->priv = g_new0(KzBookmarksViewPriv, 1);
-	view->priv->include_top = TRUE;
-	view->priv->folder_only = FALSE;
-	view->priv->tree_mode   = TRUE;
-	view->priv->editable    = TRUE;
+	priv->include_top = TRUE;
+	priv->folder_only = FALSE;
+	priv->tree_mode   = TRUE;
+	priv->editable    = TRUE;
 }
 
 
@@ -283,9 +284,12 @@ kz_bookmarks_view_set_root_folder (KzBookmarksView *view,
 				   gboolean editable)
 {
 	GtkTreeModel *model;
+	KzBookmarksViewPrivate *priv;
 
 	g_return_if_fail(KZ_IS_BOOKMARKS_VIEW(view));
 	g_return_if_fail(!top_folder || kz_bookmark_is_folder(top_folder));
+	
+	priv = KZ_BOOKMARKS_VIEW_GET_PRIVATE (view);
 
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(view));
 	gtk_tree_store_clear(GTK_TREE_STORE(model));
@@ -297,10 +301,10 @@ kz_bookmarks_view_set_root_folder (KzBookmarksView *view,
 		view->root_folder = NULL;
 	}
 
-	view->priv->tree_mode   = tree_mode;
-	view->priv->include_top = include_top;
-	view->priv->folder_only = folder_only;
-	view->priv->editable    = editable;
+	priv->tree_mode   = tree_mode;
+	priv->include_top = include_top;
+	priv->folder_only = folder_only;
+	priv->editable    = editable;
 
 	if (!top_folder) return;
 
@@ -447,6 +451,7 @@ static gboolean
 needs_refresh (KzBookmarksView *view, KzBookmark *bookmark)
 {
 	KzBookmark *parent;
+	KzBookmarksViewPrivate *priv = KZ_BOOKMARKS_VIEW_GET_PRIVATE (view);
 
 	if (!view->root_folder)
 		return FALSE;
@@ -455,7 +460,7 @@ needs_refresh (KzBookmarksView *view, KzBookmark *bookmark)
 		return TRUE;
 
 	/* FIXME! */
-	if (view->priv->tree_mode)
+	if (priv->tree_mode)
 		return TRUE;
 	else
 		return FALSE;
@@ -485,8 +490,10 @@ insert_bookmark(KzBookmarksView *view,
 	const gchar *title, *uri;
 	GdkPixbuf *favicon;
 	gboolean title_is_editable = TRUE, location_is_editable = TRUE;
+	KzBookmarksViewPrivate *priv;
 
 	g_return_if_fail(KZ_IS_BOOKMARKS_VIEW(view));
+	priv = KZ_BOOKMARKS_VIEW_GET_PRIVATE (view);
 
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(view));
 
@@ -579,7 +586,7 @@ insert_bookmark(KzBookmarksView *view,
 		g_object_unref(kz_favicon);
 	}
 
-	if (view->priv->editable)
+	if (priv->editable)
 	{
 		if (!kz_bookmark_is_editable(bookmark))
 		{
@@ -819,13 +826,15 @@ cb_bookmark_insert_child (KzBookmark *bookmark,
 			  KzBookmark *child, KzBookmark *sibling,
 			  KzBookmarksView *view)
 {
+	KzBookmarksViewPrivate *priv;
 	if (!needs_refresh(view, bookmark))
 		return;
 
+	priv = KZ_BOOKMARKS_VIEW_GET_PRIVATE (view);
 	connect_bookmark_signals (view, child);
 
-	if (!view->priv->folder_only || kz_bookmark_is_folder(child))
-		insert_bookmark(view, view->priv->folder_only,
+	if (!priv->folder_only || kz_bookmark_is_folder(child))
+		insert_bookmark(view, priv->folder_only,
 				child, bookmark, sibling);
 }
 
