@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmarks-view.h,v 1.4 2004/11/25 07:28:47 ikezoe Exp $
+ *  $Id: kz-bookmarks-view.h,v 1.5 2005/05/09 01:20:12 ikezoe Exp $
  */
 
 #ifndef __KZ_BOOKMARKS_VIEW_H__
@@ -37,15 +37,12 @@ G_BEGIN_DECLS
 
 typedef struct _KzBookmarksView		KzBookmarksView;
 typedef struct _KzBookmarksViewClass	KzBookmarksViewClass;
-typedef struct _KzBookmarksViewPriv	KzBookmarksViewPriv;
 
 struct _KzBookmarksView
 {
 	GtkTreeView parent;
 
 	KzBookmark *root_folder;
-
-	KzBookmarksViewPriv *priv;
 };
 
 struct _KzBookmarksViewClass
