@@ -136,7 +136,7 @@ kz_about_dialog_new (KzWindow *kz)
 
 	draw = gtk_drawing_area_new();
 	gtk_widget_set_size_request(draw, bg_width, bg_height);
-	g_signal_connect(G_OBJECT(draw), "expose_event",
+	g_signal_connect(draw, "expose_event",
 			 G_CALLBACK(cb_expose_event), NULL);
 	gtk_box_pack_start (GTK_BOX(GTK_DIALOG(about_dialog)->vbox), draw, TRUE, TRUE, 0);
 	gtk_widget_show(draw);
@@ -146,7 +146,7 @@ kz_about_dialog_new (KzWindow *kz)
 	gtk_box_pack_start (GTK_BOX(GTK_DIALOG(about_dialog)->vbox), calendar, TRUE, TRUE, 0);
 	gtk_widget_show(calendar);
 
-	g_signal_connect_swapped (G_OBJECT (about_dialog), 
+	g_signal_connect_swapped (about_dialog, 
 				  "response", 
 				  G_CALLBACK (gtk_widget_destroy),
 				  G_OBJECT (about_dialog));
