@@ -58,8 +58,6 @@ static void     kz_print_dialog_get_property       (GObject       *object,
 						    GValue        *value,
 						    GParamSpec    *pspec);
 
-static void     cb_parent_destroy                  (GtkWidget       *widget,
-						    KzPrintDialog   *print);
 static void     cb_print_to_file_toggled           (GtkToggleButton *button,
 						    KzPrintDialog   *print);
 static void     cb_print_pages_toggled             (GtkToggleButton *button,
@@ -121,6 +119,7 @@ kz_print_dialog_init (KzPrintDialog *print)
 	gtk_box_set_spacing(GTK_BOX(main_vbox), 4);
 	gtk_window_set_default_size(GTK_WINDOW(print), 600, 450);
 	gtk_window_set_icon(GTK_WINDOW(print), kz_icon);
+	gtk_window_set_destroy_with_parent(GTK_WINDOW(print), TRUE);
 
 	gtk_dialog_add_buttons(GTK_DIALOG(print),
 			       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -264,10 +263,8 @@ kz_print_dialog_constructor (GType                  type,
 	print = KZ_PRINT_DIALOG(object);
 	widget = GTK_WIDGET(print);
 
-	g_signal_connect(print->kz, "destroy",
-			 G_CALLBACK(cb_parent_destroy), print);
-
 	gtk_window_set_title(GTK_WINDOW(print), _("Print"));
+	gtk_window_set_transient_for(GTK_WINDOW(print), GTK_WINDOW(print->kz));
 
 	embed = KZ_WINDOW_CURRENT_PAGE(print->kz);
 	if (KZ_IS_EMBED(embed))
@@ -300,10 +297,6 @@ kz_print_dialog_dispose (GObject *object)
 
 	if (print->kz)
 	{
-		g_signal_handlers_disconnect_by_func
-			(print->kz,
-			 G_CALLBACK(cb_parent_destroy),
-			 print);
 		g_object_unref(print->kz);
 		print->kz = NULL;
 	}
@@ -378,14 +371,6 @@ kz_print_dialog_new (KzWindow *kz)
 }
 
 
-static void
-cb_parent_destroy(GtkWidget *widget, KzPrintDialog *print)
-{
-	g_return_if_fail (KZ_IS_PRINT_DIALOG(print));
-	gtk_widget_destroy(GTK_WIDGET(print));
-}
-
-
 static void
 cb_save_as_button_clicked (GtkWidget *widget, KzPrintDialog *print)
 {
