@@ -24,6 +24,7 @@
 #include <gtk/gtk.h>
 
 #include "kz-window.h"
+#include "kz-embed.h"
 
 G_BEGIN_DECLS
 
@@ -49,6 +50,7 @@ typedef struct
 {
 	gboolean to_file;
         const gchar *filename;
+	gchar *printer;
 	
 	KzPrintRange range;
 	gint from_page;
