@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-khtml.c,v 1.17 2005/04/01 13:25:25 ikezoe Exp $
+ *  $Id: kz-khtml.c,v 1.18 2005/05/09 01:20:12 ikezoe Exp $
  */
 
 #include <glib/gi18n.h>
@@ -27,11 +27,13 @@
 #include "gobject-utils.h"
 
 
-struct _KzKHTMLPriv
+typedef struct _KzKHTMLPrivate	KzKHTMLPrivate;
+struct _KzKHTMLPrivate
 {
 	gint cur_requests;
 	gint total_requests;
 };
+#define KZ_KHTML_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_KHTML, KzKHTMLPrivate))
 
 static void kz_khtml_class_init   (KzKHTMLClass *klass);
 static void kz_khtml_iface_init   (KzEmbedIFace *iface);
@@ -89,8 +91,6 @@ KZ_OBJECT_GET_TYPE_IFACE(kz_khtml, "KzKHTML", KzKHTML,
 			 kz_khtml_class_init, kz_khtml_init,
 			 GTK_TYPE_KHTML,
 			 kz_khtml_iface_init, KZ_TYPE_EMBED)
-KZ_OBJECT_FINALIZE(kz_khtml, KzKHTML)
-
 
 static void
 kz_khtml_class_init (KzKHTMLClass *klass)
@@ -103,7 +103,6 @@ kz_khtml_class_init (KzKHTMLClass *klass)
 	khtml_class  = (GtkKHTMLClass *) klass;
 
 	object_class->dispose   = kz_khtml_dispose;
-	object_class->finalize  = kz_khtml_finalize;
 
 	khtml_class->status     = kz_khtml_status;
 	khtml_class->load_start = kz_khtml_load_start;
@@ -116,6 +115,8 @@ kz_khtml_class_init (KzKHTMLClass *klass)
 	khtml_class->req_js_prompt   = kz_khtml_req_js_prompt;
 	khtml_class->req_auth_prompt = kz_khtml_req_auth_prompt;
 	khtml_class->req_new_window  = kz_khtml_req_new_window;
+	
+	g_type_class_add_private (object_class, sizeof(KzKHTMLPrivate));
 }
 
 
@@ -222,10 +223,11 @@ kz_khtml_iface_init (KzEmbedIFace *iface)
 static void
 kz_khtml_init (KzKHTML *khtml)
 {
+	KzKHTMLPrivate *priv = KZ_KHTML_GET_PRIVATE (khtml);
+
 	khtml->is_loading = FALSE;
-	khtml->priv = g_new0(KzKHTMLPriv, 1);
-	khtml->priv->cur_requests   = 0;
-	khtml->priv->total_requests = 0;
+	priv->cur_requests   = 0;
+	priv->total_requests = 0;
 }
 
 static void
@@ -250,27 +252,29 @@ kz_khtml_new (const gchar *url)
 static void
 kz_khtml_status (GtkKHTML *khtml, GtkKHTMLLoadStatus *status)
 {
+	KzKHTMLPrivate *priv;
 	g_return_if_fail(KZ_IS_KHTML(khtml));
 	g_return_if_fail(status);
 
+	priv = KZ_KHTML_GET_PRIVATE (khtml);
+
 	switch(status->status) {
 	case GTK_KHTML_LOADING_START:
 		KZ_KHTML(khtml)->is_loading = TRUE;
-		KZ_KHTML(khtml)->priv->cur_requests = 0;
-		KZ_KHTML(khtml)->priv->total_requests = 0;
+		priv->cur_requests = 0;
+		priv->total_requests = 0;
 		g_signal_emit_by_name(khtml, "kz-net-start");
 		break;
 	case GTK_KHTML_LOADING:
-		KZ_KHTML(khtml)->priv->cur_requests = status->totalReceived;
-		KZ_KHTML(khtml)->priv->total_requests = status->totalSize;
+		priv->cur_requests = status->totalReceived;
+		priv->total_requests = status->totalSize;
 		g_signal_emit_by_name(khtml, "kz-progress");
-		g_warning("oo");
 		break;
 	case GTK_KHTML_LOADING_COMPLETE:
 	case GTK_KHTML_LOADING_ERROR:
 		KZ_KHTML(khtml)->is_loading = FALSE;
-		KZ_KHTML(khtml)->priv->cur_requests = status->totalReceived;
-		KZ_KHTML(khtml)->priv->total_requests = status->totalSize;
+		priv->cur_requests = status->totalReceived;
+		priv->total_requests = status->totalSize;
 		g_signal_emit_by_name(khtml, "kz-net-stop");
 		break;
 	default:
@@ -476,18 +480,21 @@ kz_khtml_get_progress (KzEmbed *kzembed)
 {
 	gdouble progress;
 	KzKHTML *khtml;
+	KzKHTMLPrivate *priv;
 
 	g_return_val_if_fail(KZ_IS_KHTML(kzembed), 0.0);
 
+	priv = KZ_KHTML_GET_PRIVATE (khtml);
+
 	khtml = KZ_KHTML(kzembed);
-	if (khtml->priv->total_requests <= 0 ||
-	    khtml->priv->cur_requests <= 0)
+	if (priv->total_requests <= 0 ||
+	    priv->cur_requests <= 0)
 	{
 		return 0.0;
 	}
 
-	progress = (gdouble) khtml->priv->cur_requests
-		/ (gdouble) khtml->priv->total_requests;
+	progress = (gdouble) priv->cur_requests
+		/ (gdouble) priv->total_requests;
 
 	if (progress > 1.0)
 		return 1.0;
