@@ -19,9 +19,9 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <glib/gi18n.h>
 #include "gobject-utils.h"
 #include "kz-downloader-group.h"
-#include "intl.h"
 
 enum {
 	ADD_SIGNAL,
@@ -141,7 +141,7 @@ kz_downloader_group_dispose (GObject *object)
 KzDownloaderGroup *
 kz_downloader_group_new (void)
 {
-	KzDownloaderGroup *dlgrp = KZ_DOWNLOADER_GROUP(g_object_new(KZ_TYPE_DOWNLOADER_GROUP, NULL));
+	KzDownloaderGroup *dlgrp = g_object_new(KZ_TYPE_DOWNLOADER_GROUP, NULL);
 
 	return dlgrp;
 }
@@ -162,13 +162,13 @@ kz_downloader_group_get_instance (void)
 static void
 disconnect_signals(KzDownloaderGroup *dlgrp, KzDownloader *dl)
 {
-	g_signal_handlers_disconnect_by_func(G_OBJECT(dl),
+	g_signal_handlers_disconnect_by_func(dl,
 					     G_CALLBACK(cb_download_complete),
 					     dlgrp);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(dl),
+	g_signal_handlers_disconnect_by_func(dl,
 					     G_CALLBACK(cb_download_error),
 					     dlgrp);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(dl),
+	g_signal_handlers_disconnect_by_func(dl,
 					     G_CALLBACK(cb_download_progress),
 					     dlgrp);
 }
@@ -178,14 +178,14 @@ static void
 connect_signals (KzDownloaderGroup *dlgrp, KzDownloader *dl)
 {
 	/* connect signals */
-	g_signal_connect(G_OBJECT(dl), "completed",
+	g_signal_connect(dl, "completed",
 			 G_CALLBACK(cb_download_complete), dlgrp);
-	g_signal_connect(G_OBJECT(dl), "error",
+	g_signal_connect(dl, "error",
 			 G_CALLBACK(cb_download_error), dlgrp);	
-	g_signal_connect(G_OBJECT(dl), "io_in",
+	g_signal_connect(dl, "io_in",
 			 G_CALLBACK(cb_download_progress), dlgrp);	
 
-	g_signal_emit(G_OBJECT (dlgrp),
+	g_signal_emit(dlgrp,
 		      kz_downloader_group_signals[ADD_SIGNAL],
 		      0, dl);
 }
@@ -195,7 +195,6 @@ static void
 cb_download_complete (KzDownloader *dl, KzDownloaderGroup *dlgrp)
 {
 	g_return_if_fail(KZ_IS_DOWNLOADER_GROUP(dlgrp));
-	g_return_if_fail(KZ_IS_DOWNLOADER(dl));
 
 	disconnect_signals(dlgrp, dl);
 
@@ -207,7 +206,6 @@ static void
 cb_download_error (KzDownloader *dl, KzDownloaderGroup *dlgrp)
 {
 	g_return_if_fail(KZ_IS_DOWNLOADER_GROUP(dlgrp));
-	g_return_if_fail(KZ_IS_DOWNLOADER(dl));
 
 	disconnect_signals(dlgrp, dl);
 
@@ -219,9 +217,8 @@ static void
 cb_download_progress (KzDownloader *dl, KzDownloaderGroup *dlgrp)
 {
 	g_return_if_fail(KZ_IS_DOWNLOADER_GROUP(dlgrp));
-	g_return_if_fail(KZ_IS_DOWNLOADER(dl));
 
-	g_signal_emit(G_OBJECT (dlgrp),
+	g_signal_emit(dlgrp,
 		      kz_downloader_group_signals[PROGRESS_SIGNAL],
 		      0, dl);
 }
@@ -272,21 +269,17 @@ kz_downloader_group_add_item_with_filename (KzDownloaderGroup *dlgrp,
 }
 
 
-KzMozDownloader *
-kz_downloader_group_add_moz_downloader (KzDownloaderGroup *dlgrp,
-					gpointer aProgress,
-					const gchar *filename)
+void
+kz_downloader_group_add_downloader (KzDownloaderGroup *dlgrp,
+				    KzDownloader *dl)
 {
-	KzMozDownloader *dl;
-	g_return_val_if_fail(KZ_IS_DOWNLOADER_GROUP(dlgrp), NULL);
+	g_return_if_fail(KZ_IS_DOWNLOADER_GROUP(dlgrp));
+	g_return_if_fail(KZ_IS_DOWNLOADER(dl));
 
-	dl = kz_moz_downloader_new(aProgress,
-				   filename);
+	g_object_ref(G_OBJECT(dl));
 	dlgrp->items = g_slist_append(dlgrp->items, KZ_DOWNLOADER(dl));
 
 	connect_signals(dlgrp, KZ_DOWNLOADER(dl));
-	
-	return dl;
 }
 
 
@@ -306,9 +299,9 @@ kz_downloader_group_remove_item (KzDownloaderGroup *dlgrp, KzDownloader *dl)
 {
 	g_return_if_fail(KZ_IS_DOWNLOADER_GROUP(dlgrp));
 	g_return_if_fail(KZ_IS_DOWNLOADER(dl));
-	g_signal_emit(G_OBJECT (dlgrp),
+	g_signal_emit(dlgrp,
 		      kz_downloader_group_signals[REMOVE_SIGNAL],
 		      0, dl);
-	g_slist_remove(dlgrp->items, dl);
+	dlgrp->items = g_slist_remove(dlgrp->items, dl);
 	g_idle_add(idle_remove_item, dl);
 }
