@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-plugin.h,v 1.3 2004/11/25 07:28:47 ikezoe Exp $
+ *  $Id: kz-plugin.h,v 1.4 2005/05/09 01:20:11 ikezoe Exp $
  */
 
 #ifndef KZ_PLUGIN_H
@@ -37,15 +37,12 @@ G_BEGIN_DECLS
 
 typedef struct _KzPlugin      KzPlugin;
 typedef struct _KzPluginClass KzPluginClass;
-typedef struct _KzPluginPriv  KzPluginPriv;
 
 struct _KzPlugin
 {
 	GObject       parent;
 
 	GModule      *module;
-
-	KzPluginPriv *priv;
 };
 
 struct _KzPluginClass
