@@ -141,6 +141,8 @@ kz_profile_class_init (KzProfileClass *klass)
 static void
 kz_profile_init (KzProfile *profile)
 {
+	profile->save_eachtime = TRUE;
+	
 	profile->edit    = FALSE;
 	profile->file    = NULL;
 	profile->subfile = NULL;
@@ -195,7 +197,7 @@ kz_profile_dispose (GObject *object)
 KzProfile *
 kz_profile_new (void)
 {
-	KzProfile *profile = KZ_PROFILE(g_object_new(KZ_TYPE_PROFILE, NULL));
+	KzProfile *profile = g_object_new(KZ_TYPE_PROFILE, NULL);
 	return profile;
 }
 
@@ -216,7 +218,7 @@ const static gchar hex[16]={'0', '1', '2', '3', '4', '5', '6', '7',
  * flag,TRUE:signed,FALSE:unsigned
  * RET,TRUE:normal exit,FALSE:error
  */
-gboolean
+static gboolean
 misc_str_to_val(gint *value,const gchar *str,const gint radix,
 		const gboolean flag)
 {
@@ -284,7 +286,7 @@ misc_str_to_val(gint *value,const gchar *str,const gint radix,
  * flag,TRUE:signed,FALSE:unsigned
  * RET,array of value
  */
-guint8 *
+static guint8 *
 misc_str_to_array(gint *size,const gchar *text,
 		  const gint radix,const gboolean flag)
 {
@@ -765,7 +767,7 @@ kz_profile_set_value (KzProfile *profile,
 				p->next = NULL;
 				profile->list = p;
 			}
-			g_signal_emit(G_OBJECT(profile),
+			g_signal_emit(profile,
 				      kz_profile_signals[SECTION_ADDED_SIGNAL],
 				      quark, p->section);
 		}
@@ -785,7 +787,7 @@ kz_profile_set_value (KzProfile *profile,
 		q->next = p;
 		if (p->next)
 			p->next->prev = p;
-		g_signal_emit(G_OBJECT(profile),
+		g_signal_emit(profile,
 			      kz_profile_signals[KEY_ADDED_SIGNAL],
 			      quark, p->section, p->key);
 	}
@@ -824,11 +826,14 @@ kz_profile_set_value (KzProfile *profile,
 	p->value = strchr(p->data,'=') + 1;
 	profile->edit = TRUE;
 
-	g_signal_emit(G_OBJECT(profile), kz_profile_signals[CHANGED_SIGNAL],
+	g_signal_emit(profile, kz_profile_signals[CHANGED_SIGNAL],
 		      quark, p->section, p->key, old_value);
 
 	g_free(old_value);
 
+	if (profile->save_eachtime)
+		kz_profile_save (profile);
+
 	return TRUE;
 }
 
@@ -890,12 +895,15 @@ kz_profile_delete_section (KzProfile *profile, const gchar *section)
 	}
 
 	quark = g_quark_from_string(section_tmp);
-	g_signal_emit(G_OBJECT(profile),
+	g_signal_emit(profile,
 		      kz_profile_signals[SECTION_DELETED_SIGNAL],
 		      quark, section_tmp);
 
 	g_free(section_tmp);
 
+	if (profile->save_eachtime)
+		kz_profile_save (profile);
+
 	return result;
 }
 
@@ -941,13 +949,16 @@ gboolean kz_profile_delete_key (KzProfile *profile,
 	}
 
 	quark = g_quark_from_string(section_tmp);
-	g_signal_emit(G_OBJECT(profile),
+	g_signal_emit(profile,
 		      kz_profile_signals[KEY_DELETED_SIGNAL],
 		      quark, section_tmp, key_tmp);
 
 	g_free(section_tmp);
 	g_free(key_tmp);
 
+	if (profile->save_eachtime)
+		kz_profile_save (profile);
+
 	return result;
 }
 
@@ -1047,3 +1058,10 @@ kz_profile_enum_key (KzProfile *profile,
 	}
 	return glist;
 }
+
+void
+kz_profile_set_save_each_time (KzProfile *profile, gboolean save)
+{
+	profile->save_eachtime = save;
+}
+
