@@ -27,39 +27,52 @@
 #include <stdlib.h>
 #include <string.h>
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include "kazehakase.h"
 #include "kz-icons.h"
 #include "kz-window.h"
 #include "kz-actions-tab.h"
 #include "kz-xbel.h"
-#include "intl.h"
 #include "locale.h"
 #include "utils.h"
 #include "estsearch.h"
 #include "mozilla.h"
-
-#ifdef USE_GTK_2_2
-#include "gtk24backports.h"
+#if (GLIB_MAJOR_VERSION == 2) && ((GLIB_MINOR_VERSION < 5) || \
+		((GLIB_MINOR_VERSION >= 5) && (GLIB_MICRO_VERSION < 4)))
+#include "goption.h"
 #endif
 
 KzProfile      *kz_global_profile = NULL;
-KzProfile      *kz_session        = NULL;
 KzProfile      *kz_proxy          = NULL;
 KzRootBookmark *kz_bookmarks      = NULL;
 #if USE_MIGEMO
 Migemo         *migemo            = NULL;
 #endif
-static gchar *usage =
-N_("Usage: kazehakase [OPTION...] [URI...]\n"
-"   -a, --action \"Action Name\"              Execute action\n"
-"   -h, --help                              Show this help\n"
-"   -v, --version                           Show the version\n"
-);
+
+static gchar** action_array;
+static gchar* geometry_string;
+static gboolean show_version;
+
+static GOptionEntry entries[] = {
+	{ "action", 'a', 0, G_OPTION_ARG_STRING_ARRAY, &action_array, "Execute action", NULL},
+	{ "geometry", 'g', 0, G_OPTION_ARG_STRING, &geometry_string, " Position the window on the screen", NULL },
+	{ "version", 'v', 0, G_OPTION_ARG_NONE, &show_version, "Show this version", NULL },
+	{ NULL }
+};
+
+static const gchar parameter_string[] = "URI ...";
+
+static GOptionContext *context;
+static GOptionGroup *main_group;
+
+gboolean is_restoring_session = FALSE;
 
 gboolean exists_estindex = FALSE;
 gchar   *estversion;
 
+static void activate_action(const gchar *text);
+
 /******************************************************************************
  *                                                                            *
  *                                 UI Level                                   *
@@ -128,26 +141,109 @@ kz_ui_level_to_str (KzUILevel level)
 }
 
 
-const gchar *
-kz_ui_level_to_suffix (KzUILevel level)
-{
-	switch (level)
-	{
-	case KZ_UI_LEVEL_CUSTOM:
-		return "\0";
-	case KZ_UI_LEVEL_EXPERT:
-		return "Ex";
-	case KZ_UI_LEVEL_MEDIUM:
-		return "Med";
-	case KZ_UI_LEVEL_BEGINNER:
-		return "Beg";
-	default:
-		break;
-	}
+/******************************************************************************
+ *                                                                            *
+ *                       arguments parser                                     *
+ *                                                                            *
+ ******************************************************************************/
+/* split_string is taken from glib/tests/option-test.c */
 
-	return NULL;
+static gchar **
+split_string (const char *str, int *argc)
+{
+	gchar **argv;
+	int len;
+  
+	argv = g_strsplit (str, "\n", -1);
+
+	for (len = 0; argv[len] != NULL; len++);
+	
+	if (argc)
+		*argc = len;
+	
+	return argv;
 }
 
+static gboolean
+pre_parse_cb (GOptionContext *context,
+		GOptionGroup   *group,
+		gpointer	       data,
+		GError        **error)
+{
+#if 0
+	if(action_array)
+	{
+                /* free action_array before using */
+		g_strfreev (action_array);
+		action_array = NULL;
+	}
+#endif
+	return TRUE;
+}
+
+static gboolean
+post_parse_cb (GOptionContext *context,
+		 GOptionGroup   *group,
+		 gpointer	  data,
+		 GError        **error)
+{
+        /* XXX: Is there anything to do? */
+	return TRUE;
+}
+
+static void
+parse_error_cb (GOptionContext *context,
+		 GOptionGroup   *group,
+		 gpointer	  data,
+		 GError        **error)
+{
+	fprintf (stderr, "%s\n", (*error)->message);
+	g_error_free (*error);
+	return;
+}
+
+static void
+free_goption()
+{
+	g_free (geometry_string);
+	g_strfreev (action_array);
+	g_option_context_free (context);
+}
+
+/* XXX: This function has side effect! */
+static void
+process_args(int argc, char** argv)
+{
+	int i;
+	static int count = 0;
+	GList* list;
+	KzWindow *kz;
+
+#warning This function has side effect!
+
+	list = kz_window_get_window_list();
+	if (!list || !list->data || !KZ_IS_WINDOW(list->data))
+		return;
+
+	if(action_array)
+	{
+                /* show actions */
+		for(; action_array[count] != NULL; count++)
+		{
+			activate_action(action_array[count]);
+		}
+	}
+	
+	kz = KZ_WINDOW(list->data);
+	for(i = 1; i < argc; i++)
+	{
+		gchar *uri = complement_scheme(argv[i]);
+		gdk_window_raise(GTK_WIDGET(kz)->window);
+
+		kz_window_open_new_tab(kz, uri);
+		g_free(uri);
+	}
+}
 
 /******************************************************************************
  *                                                                            *
@@ -206,10 +302,11 @@ cb_selection_get(GtkWidget *widget,
 
 
 static void
-activate_action(GList *window_list, const gchar *text)
+activate_action(const gchar *text)
 {
 	KzWindow *kz;
 	KzTabLabel *kztab;
+	GList *window_list;
 	GtkWidget *widget;
 	GtkAction *action;
 	gchar *action_name;
@@ -220,6 +317,8 @@ activate_action(GList *window_list, const gchar *text)
 	};
 	gint window_id = 0, tab_id = -1 /* -1 is current tab */;
 
+	window_list = kz_window_get_window_list();
+	
 	if (!strncmp(text, "KzWindowTabPopup", 16))
 	{
 		gchar *p1, *p2, *p3;
@@ -317,33 +416,18 @@ cb_selection_received(GtkWidget *widget,
 	}
 	else if (data->selection == atom_kz1 && data->length > 0) 
 	{
-		GList *list = kz_window_get_window_list();
-		KzWindow *kz;
+		gint argc;
 		gchar **argv;
-		gint i;
+		gboolean retval;
+		GError *error = NULL;
 
-		if (!list || !list->data || !KZ_IS_WINDOW(list->data)) return;
-		kz = list->data;
-		gdk_window_raise(GTK_WIDGET(kz)->window);
 
 		/* open URL */
-		argv = g_strsplit(data->data, "\n", -1);
-		for (i = 0; argv[i]; i++)
-		{
-			if ((!strcmp(argv[i], "--action") ||
-			     !strcmp(argv[i], "-a")) &&
-			    *argv[i+1] &&
-			    argv[i+1])
-			{
-				activate_action(list, argv[i+1]);
-				i++;
-				continue;
-			}
+		argv = split_string(data->data, &argc);
 
-			gchar *uri = complement_scheme(argv[i]);
-			kz_window_open_new_tab(kz, uri);
-			g_free(uri);
-		}
+		retval = g_option_context_parse (context, &argc, &argv, &error);
+		if(retval)
+			process_args(argc, argv);
 
 		g_strfreev(argv);
 	}
@@ -365,12 +449,12 @@ check_kazehakase_process (int argc, char *argv[])
 
 	gtk_selection_add_targets(window, atom_kz0, targets, 1);
 	gtk_selection_add_targets(window, atom_kz1, targets, 1);
-	g_signal_connect (G_OBJECT(window), "selection-get",
+	g_signal_connect (window, "selection-get",
 			  G_CALLBACK(cb_selection_get), window);
-	g_signal_connect (GTK_OBJECT(window), "selection-received",
+	g_signal_connect (window, "selection-received",
 			  G_CALLBACK(cb_selection_received), window);
 
-	for (i = 1; i < argc; i++)
+	for (i = 0; i < argc; i++)
 	{
 		gint len;
 
@@ -441,15 +525,35 @@ clean_history_cache (void)
 			for (slist = purge_list; slist; slist = slist->next)
 				purge_files[n--] = slist->data;
 
-			g_slist_free(purge_list);
 			/* optimize and purge history index */
 			if (exists_estindex)
 				estsearch_purge_index(purge_files);
 		 
 			g_strfreev(purge_files);
+			g_slist_free(purge_list);
 		}
 	}
 }
+
+static void
+prepare_dir (void)
+{
+	/* for thumbnails */
+	make_thumbnails_dir();
+	
+	/* for favicon */
+	make_dir("favicon");
+
+	/* for popup */
+	make_dir("popup");
+
+	/* for smart bookmark input history */
+	make_dir("smartbookmark_history");
+	
+	/* for storing form data */
+	make_dir("form_data");
+}
+
 /******************************************************************************
  *                                                                            *
  *                                  Main                                      *
@@ -458,9 +562,9 @@ clean_history_cache (void)
 static void
 open_app_info (void)
 {
-	gchar *sysconf_file, *conf_file, *session_file;
+	gchar *sysconf_file, *conf_file;
 	gchar *bookmark_file, *sys_bookmark_file;
-	gchar *clip_file;
+	gchar *clip_file, *current_session_file;
 	gchar *bookmark_bar_file, *sys_bookmark_bar_file;
 	gchar *smartbookmark_file, *sys_smartbookmark_file;
 	gchar *accel_prefs_file;
@@ -469,21 +573,15 @@ open_app_info (void)
 
 	/* load prefs */
 	sysconf_file = g_strdup(KZ_SYSCONFDIR "/kzrc");
-	conf_file = g_build_filename(g_get_home_dir(), ".kazehakase",
+	conf_file = g_build_filename(g_get_home_dir(),
+				     "."PACKAGE,
 				     "kzrc", NULL);
 	
 	kz_global_profile = kz_profile_open(conf_file, sysconf_file);
 
-	/* load sessions */
-	session_file = g_build_filename(g_get_home_dir(),
-				   	".kazehakase",
-					"sessionrc",
-				   	NULL);
-	kz_session = kz_profile_open(session_file, NULL);
-
 	/* load bookmarks */
 	bookmark_file         = g_build_filename(g_get_home_dir(),
-					    	 ".kazehakase",
+					    	 "."PACKAGE,
 					    	 "bookmarks.xml",
 					    	 NULL);
 	sys_bookmark_file     = g_build_filename(KZ_SYSCONFDIR,
@@ -491,23 +589,27 @@ open_app_info (void)
 					    	 NULL);
 
         bookmark_bar_file     = g_build_filename(g_get_home_dir(),
-					    	 ".kazehakase",
+					    	 "."PACKAGE,
 						 "bookmarkbar.xml",
 					    	 NULL);
 	sys_bookmark_bar_file = g_build_filename(KZ_SYSCONFDIR,
 					    	 "bookmarkbar.xml",
 					    	 NULL);
 	clip_file             = g_build_filename(g_get_home_dir(),
-					    	 ".kazehakase",
+					    	 "."PACKAGE,
 						 "clip.xml",
 					    	 NULL);
         smartbookmark_file    = g_build_filename(g_get_home_dir(),
-					    	 ".kazehakase",
+					    	 "."PACKAGE,
 					    	 "smartbookmarks.xml",
 					    	 NULL);
 	sys_smartbookmark_file= g_build_filename(KZ_SYSCONFDIR,
 					    	 "smartbookmarks.xml",
 					    	 NULL);
+	current_session_file  = g_build_filename(g_get_home_dir(),
+						 "."PACKAGE,
+						 "current_session.xml",
+					    	 NULL);
 	
 	kz_bookmarks = kz_root_bookmark_new(bookmark_file, sys_bookmark_file,
 					    clip_file, NULL);
@@ -518,18 +620,19 @@ open_app_info (void)
 	kz_root_bookmark_add_bookmark_bar_file(kz_bookmarks,
 					       bookmark_bar_file,
 					       sys_bookmark_bar_file);
-
+	kz_root_bookmark_add_current_session_file(kz_bookmarks,
+						  current_session_file);
 
 	/* Load other prefs... */
 	accel_prefs_file = g_build_filename (g_get_home_dir(),
-					     ".kazehakase",
+					     "."PACKAGE,
 					     "keyaccelrc",
 					     NULL);
 	gtk_accel_map_load (accel_prefs_file);
 
 	sysproxy_file = g_build_filename(KZ_SYSCONFDIR, "proxyrc", NULL);
 	proxy_file = g_build_filename (g_get_home_dir(),
-				       ".kazehakase",
+				       "."PACKAGE,
 				       "proxyrc", NULL);
 	kz_proxy = kz_profile_open(proxy_file, sysproxy_file);
 
@@ -547,15 +650,15 @@ open_app_info (void)
 		estversion = estsearch_get_version();
 	}
 
-	/* make dir for thumbnails */
-	make_thumbnails_dir();
+	/* make dirs */
+	prepare_dir();
 
 	g_free(sysconf_file);
 	g_free(conf_file);
-	g_free(session_file);
 	g_free(bookmark_file);
 	g_free(sys_bookmark_file);
 	g_free(clip_file);
+	g_free(current_session_file);
 	g_free(bookmark_bar_file);
 	g_free(sys_bookmark_bar_file);
 	g_free(smartbookmark_file);
@@ -572,7 +675,7 @@ close_app_info (void)
 	gchar *accel_prefs_file;
 
 	accel_prefs_file = g_build_filename (g_get_home_dir(),
-					     ".kazehakase",
+					     "."PACKAGE,
 					     "keyaccelrc",
 					     NULL);
 
@@ -588,7 +691,6 @@ close_app_info (void)
 	g_object_unref(G_OBJECT(kz_bookmarks));
 
 	kz_profile_close(kz_global_profile);
-	kz_profile_close(kz_session);
 	kz_profile_close(kz_proxy);
 
 	if (estversion)
@@ -605,104 +707,193 @@ close_app_info (void)
 	}
 #endif	
 	kz_global_profile = NULL;
-	kz_session        = NULL;
 	kz_proxy          = NULL;
 	kz_bookmarks      = NULL;
+	
+	free_goption();
 }
 
+static gboolean
+restore_session (void)
+{
+	GList *list, *node;
+	gint pos = 0;
+	gchar *current_session;
+	KzBookmarkFile *tmp_bookmark;
+
+	/* reload from current session file */
+	current_session  = g_build_filename(g_get_home_dir(),
+					    "."PACKAGE,
+					    "current_session.xml",
+					     NULL);
+	if (!g_file_test(current_session, G_FILE_TEST_EXISTS))
+	{
+		g_free(current_session);
+		return FALSE;
+	}
+	tmp_bookmark = kz_bookmark_file_new(current_session,
+					   _("Current Session"),
+					   "XBEL");
+	g_free(current_session);
+	kz_bookmark_file_load(tmp_bookmark);
+	
+	list = kz_bookmark_get_children(KZ_BOOKMARK(tmp_bookmark));
+	if (!g_list_length(list))
+	{
+		g_list_free(list);
+		g_object_unref(tmp_bookmark);
+		return FALSE;
+	}
+	
+	/* remove old entry from kz_bookmarks->current_session */
+	kz_bookmark_remove_all(kz_bookmarks->current_session);
+
+	is_restoring_session = TRUE;
+	/* windows */
+	for (node = list; node; node = g_list_next(node))
+	{
+		GList *tabs, *tabnode;
+		KzWindow *window;
+		KzBookmark *window_bookmark = KZ_BOOKMARK(node->data);
+		tabs = kz_bookmark_get_children(window_bookmark);
+
+		window = KZ_WINDOW(kz_window_new(NULL));
+	       	/* 
+		 * gtk_window_pargse_geometry() needs to be called 
+		 * before gtk_widget_show().
+		 */ 
+		if(geometry_string)
+		{
+			gtk_window_parse_geometry(GTK_WINDOW(window),
+						  geometry_string);
+		}
+		gtk_widget_show(GTK_WIDGET(window));
+	
+		/* tabs */
+		for (tabnode = tabs; tabnode; tabnode = g_list_next(tabnode))
+		{
+			GtkWidget *widget;
+			KzTabLabel *kztab;
+			KzBookmark *child = KZ_BOOKMARK(tabnode->data);
+			widget = kz_window_open_new_tab_at_tail(window, NULL);
+			kztab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(
+					     GTK_NOTEBOOK(window->notebook),
+					     widget));
+			kz_tab_label_set_history(KZ_TAB_LABEL(kztab), child);
+
+			if (kz_bookmark_get_lock(child))
+			{
+				kz_tab_label_set_lock(kztab, TRUE);
+			}
+			if (kz_bookmark_get_auto_refresh(child))
+			{
+				kz_tab_label_set_auto_refresh(kztab, TRUE);
+			}
+		}
+		g_list_free(tabs);
+		pos = kz_bookmark_get_current(window_bookmark);
+		gtk_notebook_set_current_page(GTK_NOTEBOOK(window->notebook), pos);
+	}
+
+	g_list_free(list);
+	g_object_unref(tmp_bookmark);
+
+	is_restoring_session = FALSE;
+
+	return TRUE;
+}
 
 int
 main (int argc, char *argv[])
 {
 	KzWindow *kz = NULL;
 	GtkWidget *dupl_check_server = NULL;
-	gint i;
+	gchar **argv_copy;
+	gint argc_copy = argc;
+	gboolean retval;
+	GError *error = NULL;
+	gboolean restore = FALSE;
 
-	/* initialize */
+        /* initialize */
 	setlocale(LC_ALL, "");
 	bindtextdomain(PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset(PACKAGE, "UTF-8");
 	textdomain(PACKAGE);
 
+        /* initialize goption */
+	context = g_option_context_new (parameter_string);
+	g_option_context_add_main_entries (context, entries, NULL);
+	main_group = g_option_context_get_main_group (context);
+
+        /* set hooks */
+	g_option_group_set_parse_hooks (main_group,
+					pre_parse_cb, post_parse_cb);
+	g_option_group_set_error_hook (main_group,
+				       parse_error_cb);
+        /* set to ignore unknown options */
+	g_option_context_set_ignore_unknown_options (context, TRUE);
+
 	gtk_init(&argc, &argv);
 
-	for (i = 1; i < argc; i++)	
+        /* copy argv (ant argc) so as to preserve original arguments */
+	argv_copy = g_strdupv(argv);
+
+        /* g_option_context_parse changes argc_copy and argv_copy so as to
+	   process remaining arguments */
+	retval = g_option_context_parse (context, &argc_copy, &argv_copy, &error);
+	if(retval && show_version)
 	{
-		if (!strncmp(argv[i], "--version", 9) ||
-		    !strncmp(argv[i], "-v", 2))
-		{
-			g_print("%s %s\n", PACKAGE, VERSION);
-			return 0;
-		}
-		else if (!strncmp(argv[i], "--help", 6)||
-			 !strncmp(argv[i], "-h", 2))
-		{
-			g_print(_(usage));
-			return 0;
-		}
+	        /* show version number and exit */
+		g_print("%s %s\n", PACKAGE, VERSION);
+		free_goption();
+		g_strfreev(argv_copy);
+		exit(0);
 	}
 
-#ifdef USE_GTK_2_2
-	gtk24backports_init();
-#endif
 	/* find kazehakase process */
 	dupl_check_server = check_kazehakase_process(argc, argv);
 	if (!dupl_check_server)
 	{
+		free_goption();
+		g_strfreev(argv_copy);
 		/* FIXME! show message */
 		return 0;   /* found kazehakase process */
 	}
 
 	/* Load preference */
 	open_app_info();
-
-	/* create window */	
-	kz = KZ_WINDOW(kz_window_new(NULL));
-
-       	/* 
-	 * gtk_window_pargse_geometry() needs to be called 
-	 * before gtk_widget_show().
-	 */ 
-	for (i = 1; i < argc; i++)
+	
+	/* restore session */
+	KZ_CONF_GET("Session", "restore",
+		    restore, BOOL);
+	if (restore)
 	{
-		if (!strcmp(argv[i], "-geometry") &&
-		     *argv[i+1] && argv[i+1])
+		GList *window_list;
+		restore = restore_session();
+		window_list = kz_window_get_window_list();
+		if (window_list)
+			kz = KZ_WINDOW(window_list->data);
+	}
+	if (!restore)
+	{
+		/* create window */	
+		kz = KZ_WINDOW(kz_window_new(NULL));
+
+	       	/* 
+		 * gtk_window_pargse_geometry() needs to be called 
+		 * before gtk_widget_show().
+		 */ 
+		if(geometry_string)
 		{
 			gtk_window_parse_geometry(GTK_WINDOW(kz),
-						  argv[i+1]);
-			i++;
-			continue;
+						  geometry_string);
 		}
+		gtk_widget_show(GTK_WIDGET(kz));
 	}
 
-	gtk_widget_show(GTK_WIDGET(kz));
-	
 	/* process arguments */
-	for (i = 1; i < argc; i++)
-	{
-		gchar *uri;
-		if ((!strcmp(argv[i], "--action") ||
-		     !strcmp(argv[i], "-a")) &&
-		    *argv[i+1] &&
-		    argv[i+1])
-		{
-			GList* list = kz_window_get_window_list();
-			activate_action(list, argv[i+1]);
-			i++;
-			continue;
-		}
-		else if (!strcmp(argv[i], "-geometry") &&
-		         *argv[i+1] && argv[i+1])
-		{
-			i++;
-			continue;
-		}
-
-		/* open URL */
-		uri = complement_scheme(argv[i]);
-		kz_window_open_new_tab(kz, uri);
-		g_free(uri);
-	}
+	process_args(argc_copy, argv_copy);
+	g_strfreev (argv_copy);
 
 	/* event loop */
 	gtk_main();
