@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.7 2005/03/14 14:17:45 ikezoe Exp $
+ *  $Id: GtkNSSDialogs.cpp,v 1.8 2005/04/04 09:02:42 ikezoe Exp $
  */
 
 /*
@@ -270,6 +270,9 @@ GtkNSSDialogs::ConfirmMismatchDomain (nsIInterfaceRequestor *ctx,
 
 	nsEmbedString commonName;
 	cert->GetCommonName (commonName);
+	
+	nsEmbedCString cCommonName;
+	NS_UTF16ToCString(commonName, NS_CSTRING_ENCODING_UTF8, cCommonName);
 
 	nsEmbedCString cTargetURL(targetURL);
 
@@ -277,7 +280,7 @@ GtkNSSDialogs::ConfirmMismatchDomain (nsIInterfaceRequestor *ctx,
                                                cTargetURL.get());
 
 	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
-						commonName.get());
+						cCommonName.get());
 
         first = g_strdup_printf (_("The site %s returned security information for "
 				   "%s. It is possible that someone is intercepting "
@@ -318,8 +321,11 @@ GtkNSSDialogs::ConfirmUnknownIssuer (nsIInterfaceRequestor *ctx,
 	nsEmbedString commonName;
 	cert->GetCommonName (commonName);
 
+	nsEmbedCString cCommonName;
+	NS_UTF16ToCString(commonName, NS_CSTRING_ENCODING_UTF8, cCommonName);
+
 	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
-						commonName.get());
+						cCommonName.get());
 
 	secondary = g_strdup_printf
 		           (_("Your browser was unable to trust %s. "
@@ -413,6 +419,9 @@ GtkNSSDialogs::ConfirmCertExpired (nsIInterfaceRequestor *ctx,
 	nsEmbedString commonName;
 	cert->GetCommonName (commonName);
 
+	nsEmbedCString cCommonName;
+	NS_UTF16ToCString(commonName, NS_CSTRING_ENCODING_UTF8, cCommonName);
+
 	LL_DIV (normalizedTime, timeToUse, PR_USEC_PER_SEC);
 	LL_L2UI (t, normalizedTime);
 	/* To translators: this a time format that is used while displaying the
@@ -423,7 +432,7 @@ GtkNSSDialogs::ConfirmCertExpired (nsIInterfaceRequestor *ctx,
 	fdate = g_locale_to_utf8 (formattedDate, -1, NULL, NULL, NULL);
 
 	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
-					        commonName.get());
+					        cCommonName.get());
 
 	secondary = g_strdup_printf (text, ttCommonName, fdate);
 
@@ -468,10 +477,13 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 	nsEmbedString commonName;
 	cert->GetCommonName (commonName);
 
+	nsEmbedCString cCommonName;
+	NS_UTF16ToCString(commonName, NS_CSTRING_ENCODING_UTF8, cCommonName);
+
 	nsEmbedCString cTargetURL(targetURL);
 
 	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
-						commonName.get());
+						cCommonName.get());
 
 	ttTargetUrl = g_markup_printf_escaped ("\"<tt>%s</tt>\"",
 				               cTargetURL.get());
@@ -533,8 +545,11 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 	nsEmbedString commonName;
 	cert->GetCommonName (commonName);
 
+	nsEmbedCString cCommonName;
+	NS_UTF16ToCString(commonName, NS_CSTRING_ENCODING_UTF8, cCommonName);
+
 	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"",
-						commonName.get());
+						cCommonName.get());
 
 	tertiary = g_strdup_printf (_("Trust %s to identify:"), ttCommonName);
 	g_free (ttCommonName);
