@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozillaPrivate.h,v 1.3 2005/03/16 01:05:49 ikezoe Exp $
+ *  $Id: MozillaPrivate.h,v 1.6 2005/06/27 23:34:14 ikezoe Exp $
  */
 
 /*
@@ -23,12 +23,20 @@
  *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
  */
 
+#ifndef __MOZILLA_PRIVATE_H__
+#define __MOZILLA_PRIVATE_H__
+
 #include <glib.h>
+#include <gtk/gtk.h>
 #include <nsIPrintSettings.h>
+#include <nsIDOMWindow.h>
 #include <nsIDOMDocument.h>
 #include <nsIDOMRange.h>
 #include <nsISelection.h>
 #include <nsIDocShell.h>
+#include <nsIBaseWindow.h>
+#include <nsIDOMEventReceiver.h>
+#include <nsIPref.h>
 
 namespace MozillaPrivate
 {
@@ -38,4 +46,20 @@ namespace MozillaPrivate
 	gboolean  GetSelectedRange    (nsIDOMDocument *domDoc, nsIDOMRange *range,
 				       nsISelection *selection, gboolean backward);
 	gboolean  SetZoomOnDocShell   (float aZoom, nsIDocShell *DocShell);
+	GdkWindow *GetGdkWindow       (nsIBaseWindow *window);
+	gboolean  GetEventReceiver    (nsIDOMWindow *domWindow, nsIDOMEventReceiver **receiver);
+	gchar    *GetURIForDOMWindow  (nsIDOMWindow *aDOMWindow);
 }
+
+class MozillaEmbedPrivate {
+	public:
+	MozillaEmbedPrivate();
+  	~MozillaEmbedPrivate();
+  	static nsIPref                *sPrefs;
+  	static void *sProfileDirServiceProvider;
+
+  	static nsresult StartupProfile (const char *sProfileDir, const char *sProfileName);
+  	static void     ShutdownProfile(void);
+};
+
+#endif /* __MOZILLA_PRIVATE_H__ */
