@@ -275,11 +275,11 @@ kz_tab_tree_init (KzTabTree *tabtree)
 					   "foreground", COLUMN_TITLE_COLOR);
 	gtk_tree_view_append_column(tree_view, column);
 
-	g_signal_connect(G_OBJECT(tree_view), "cursor-changed",
+	g_signal_connect(tree_view, "cursor-changed",
 			 G_CALLBACK(cb_cursor_changed), tabtree);
-	g_signal_connect(G_OBJECT(tree_view), "button-release-event",
+	g_signal_connect(tree_view, "button-release-event",
 			 G_CALLBACK(cb_tree_view_button_release), tabtree);
-	g_signal_connect(G_OBJECT(tree_view), "scroll-event",
+	g_signal_connect(tree_view, "scroll-event",
 			 G_CALLBACK(cb_scroll_event), tabtree);
 
 	tabtree->sidebar   = NULL;
@@ -317,13 +317,13 @@ kz_tab_tree_constructor (GType                  type,
 
 	gtk_tree_view_expand_all(tabtree->tree_view);
 
-	g_signal_connect(G_OBJECT(tabtree->sidebar->kz->notebook), "switch-page",
+	g_signal_connect(tabtree->sidebar->kz->notebook, "switch-page",
 			 G_CALLBACK(cb_switch_page), tabtree);
-	g_signal_connect(G_OBJECT(tabtree->sidebar->kz), "append-tab",
+	g_signal_connect(tabtree->sidebar->kz, "append-tab",
 			 G_CALLBACK(cb_append_tab), tabtree);
-	g_signal_connect(G_OBJECT(tabtree->sidebar->kz), "remove-tab",
+	g_signal_connect(tabtree->sidebar->kz, "remove-tab",
 			 G_CALLBACK(cb_remove_tab), tabtree);
-	g_signal_connect(G_OBJECT(tabtree->sidebar->kz), "reorder-tab",
+	g_signal_connect(tabtree->sidebar->kz, "reorder-tab",
 			 G_CALLBACK(cb_reorder_tab), tabtree);
 
 	return object;
@@ -342,19 +342,19 @@ kz_tab_tree_dispose (GObject *obj)
 		if (kz)
 		{
 			g_signal_handlers_disconnect_by_func
-				(G_OBJECT(kz->notebook),
+				(kz->notebook,
 				 G_CALLBACK(cb_switch_page),
 				 tabtree);
 			g_signal_handlers_disconnect_by_func
-				(G_OBJECT(kz),
+				(kz,
 				 G_CALLBACK(cb_append_tab),
 				 tabtree);
 			g_signal_handlers_disconnect_by_func
-				(G_OBJECT(kz),
+				(kz,
 				 G_CALLBACK(cb_remove_tab),
 				 tabtree);
 			g_signal_handlers_disconnect_by_func
-				(G_OBJECT(kz),
+				(kz,
 				 G_CALLBACK(cb_reorder_tab),
 				 tabtree);
 		}
@@ -491,13 +491,13 @@ build_tab_tree (KzTabTree *tabtree, GNode *parent)
 					   COLUMN_TITLE_COLOR, color,
 					   COLUMN_EMBEDER,     kzembed,
 					   COLUMN_TERMINATOR);
-			g_signal_connect(G_OBJECT(kzembed), "kz-title",
+			g_signal_connect(kzembed, "kz-title",
 					 G_CALLBACK(cb_title_changed),
 					 tabtree);
-			g_signal_connect(G_OBJECT(kzembed), "kz-net-start",
+			g_signal_connect(kzembed, "kz-net-start",
 					 G_CALLBACK(cb_net_start),
 					 tabtree);
-			g_signal_connect(G_OBJECT(kzembed), "kz-net-stop",
+			g_signal_connect(kzembed, "kz-net-stop",
 					 G_CALLBACK(cb_net_stop),
 					 tabtree);
 
@@ -557,13 +557,13 @@ build_tab_list (KzTabTree *tabtree)
 					   COLUMN_TITLE_COLOR, color,
 					   COLUMN_EMBEDER,     kzembed,
 					   COLUMN_TERMINATOR);
-			g_signal_connect(G_OBJECT(kzembed), "kz-title",
+			g_signal_connect(kzembed, "kz-title",
 					 G_CALLBACK(cb_title_changed),
 					 tabtree);
-			g_signal_connect(G_OBJECT(kzembed), "kz-net-start",
+			g_signal_connect(kzembed, "kz-net-start",
 					 G_CALLBACK(cb_net_start),
 					 tabtree);
-			g_signal_connect(G_OBJECT(kzembed), "kz-net-stop",
+			g_signal_connect(kzembed, "kz-net-stop",
 					 G_CALLBACK(cb_net_stop),
 					 tabtree);
 
@@ -639,13 +639,13 @@ remove_embed_signal_func (GtkTreeModel *model,
 			   COLUMN_TERMINATOR);
 	g_return_val_if_fail(kzembed, FALSE);
 
-	g_signal_handlers_disconnect_by_func(G_OBJECT(kzembed),
+	g_signal_handlers_disconnect_by_func(kzembed,
 					     G_CALLBACK(cb_title_changed),
 					     tabtree);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(kzembed),
+	g_signal_handlers_disconnect_by_func(kzembed,
 					     G_CALLBACK(cb_net_start),
 					     tabtree);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(kzembed),
+	g_signal_handlers_disconnect_by_func(kzembed,
 					     G_CALLBACK(cb_net_stop),
 					     tabtree);
 
@@ -680,7 +680,6 @@ cb_cursor_changed(GtkTreeView *tree_view, KzTabTree *tabtree)
 	KzEmbed *kzembed = NULL;
 	gint num;
 
-	g_return_if_fail(GTK_IS_TREE_VIEW(tree_view));
 	g_return_if_fail(KZ_IS_TAB_TREE(tabtree));
 
 	if (tabtree->switching) return;
@@ -718,7 +717,6 @@ cb_tree_view_button_release (GtkWidget *widget, GdkEventButton *event,
 	KzEmbed *kzembed = NULL;
 	GtkWidget *label;
 
-	g_return_val_if_fail(GTK_IS_TREE_VIEW(widget), FALSE);
 	g_return_val_if_fail(KZ_IS_TAB_TREE(tabtree), FALSE);
 
 	kz = tabtree->sidebar->kz;
@@ -755,16 +753,15 @@ cb_scroll_event (GtkWidget *widget, GdkEventScroll *event, KzTabTree *tabtree)
 {
 	gboolean retval = FALSE;
 
-	g_return_val_if_fail(GTK_IS_TREE_VIEW(widget), FALSE);
 	g_return_val_if_fail(KZ_IS_TAB_TREE(tabtree), FALSE);
 
 	switch (event->direction) {
 	case GDK_SCROLL_UP:
-		g_signal_emit_by_name(GTK_TREE_VIEW(widget), "move-cursor",
+		g_signal_emit_by_name(widget, "move-cursor",
 				      GTK_MOVEMENT_DISPLAY_LINES, -1, &retval);
 		break;
 	case GDK_SCROLL_DOWN:
-		g_signal_emit_by_name(GTK_TREE_VIEW(widget), "move-cursor",
+		g_signal_emit_by_name(widget, "move-cursor",
 				      GTK_MOVEMENT_DISPLAY_LINES, 1, &retval);
 		break;
 	case GDK_SCROLL_LEFT:
@@ -787,7 +784,6 @@ cb_switch_page (GtkNotebook *notebook, GtkNotebookPage *page,
 	GtkTreeIter *iter;
 	GtkTreePath *treepath;
 
-	g_return_if_fail(GTK_IS_NOTEBOOK(notebook));
 	g_return_if_fail(KZ_IS_TAB_TREE(tabtree));
 
 	if (tabtree->switching) return;
@@ -816,7 +812,6 @@ cb_append_tab (KzWindow *kz, GtkWidget *widget, GtkWidget *parent,
 {
 	GNode *tree;
 
-	g_return_if_fail(KZ_IS_WINDOW(kz));
 	g_return_if_fail(GTK_IS_WIDGET(widget));
 	g_return_if_fail(KZ_IS_TAB_TREE(tabtree));
 
@@ -845,7 +840,6 @@ cb_remove_tab (KzWindow *kz, GtkWidget *widget,
 {
 	GNode *tree;
 
-	g_return_if_fail(KZ_IS_WINDOW(kz));
 	g_return_if_fail(GTK_IS_WIDGET(widget));
 	g_return_if_fail(KZ_IS_TAB_TREE(tabtree));
 
@@ -873,7 +867,6 @@ cb_reorder_tab (KzWindow *kz,
 		GtkWidget *widget, gint pos,
 		KzTabTree *tabtree)
 {
-	g_return_if_fail(KZ_IS_WINDOW(kz));
 	g_return_if_fail(GTK_IS_WIDGET(widget));
 	g_return_if_fail(KZ_IS_TAB_TREE(tabtree));
 
@@ -897,7 +890,6 @@ cb_net_start (KzEmbed *embed, KzTabTree *tabtree)
 	GtkTreeIter *iter;
 	gchar *title;
 
-	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_TREE(tabtree));
 
 	title = kz_embed_ensure_title(KZ_EMBED(embed));
@@ -922,7 +914,6 @@ cb_net_stop (KzEmbed *embed, KzTabTree *tabtree)
 	GtkTreeIter *iter;
 	gchar *title;
 
-	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_TREE(tabtree));
 
 	title = kz_embed_ensure_title(KZ_EMBED(embed));
@@ -947,7 +938,6 @@ cb_title_changed (KzEmbed *embed, KzTabTree *tabtree)
 	gchar *title;
 	GtkTreeIter *iter;
 
-	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_TREE(tabtree));
 
 	title = kz_embed_ensure_title(KZ_EMBED(embed));
