@@ -144,7 +144,7 @@ migemo_get_regex(const gchar *text)
 }
 
 gchar *
-migemo_get_matched_text(const gchar *body, const gchar *text)
+migemo_get_matched_text(const gchar *body, const gchar *text, const gboolean last)
 {
 	gchar *matched_text = NULL;
 	gchar *regex;
@@ -172,9 +172,12 @@ migemo_get_matched_text(const gchar *body, const gchar *text)
 		return NULL;
 	}
 
-	if (egg_regex_match(egg_regex, body, -1, 0) > 0)
+	while (egg_regex_match_next(egg_regex, body, -1, 0) > 0)
 	{
+		if (matched_text)
+			g_free(matched_text);
 		matched_text = egg_regex_fetch(egg_regex, body, 0);
+		if (!last) break;
 	}
 	egg_regex_free(egg_regex);
 	return matched_text;
