@@ -155,8 +155,6 @@ kz_entry_class_init (KzEntryClass *klass)
 static void
 kz_entry_init (KzEntry *entry)
 {
-	g_return_if_fail (KZ_IS_ENTRY (entry));
-
 	entry->backtext     = NULL;
 	entry->pixbuf       = NULL;
 	entry->stock_id     = NULL;
@@ -1524,7 +1522,7 @@ kz_entry_button_press (GtkWidget *widget,
 
 	if (event->window == entry->icon_area)
 	{
-		g_signal_emit(G_OBJECT(widget), 
+		g_signal_emit(widget, 
 			      kz_entry_signals[ICON_PRESSED_SIGNAL],
 			      0, event);
 	}
